@@ -15,16 +15,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef DEVICELINK_H
 #define DEVICELINK_H
 
 #include <QObject>
-#include <QtCrypto>
 
-#include "core/networkpacket.h"
+#include "networkpacket.h"
 
 class PairingHandler;
 class NetworkPacket;
@@ -66,9 +65,6 @@ Q_SIGNALS:
     void pairingError(const QString& error);
     void receivedPacket(const NetworkPacket& np);
 
-protected:
-    QCA::PrivateKey m_privateKey;
-
 private:
     const QString m_deviceId;
     LinkProvider* m_linkProvider;
