@@ -15,19 +15,19 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
+#include "landevicelink.h"
+
 #include <KLocalizedString>
 
-#include "landevicelink.h"
 #include "core_debug.h"
 #include "kdeconnectconfig.h"
 #include "backends/linkprovider.h"
-#include "uploadjob.h"
-#include "downloadjob.h"
 #include "socketlinereader.h"
 #include "lanlinkprovider.h"
+#include "plugins/share/shareplugin.h"
 
 LanDeviceLink::LanDeviceLink(const QString& deviceId, LinkProvider* parent, QSslSocket* socket, ConnectionStarted connectionSource)
     : DeviceLink(deviceId, parent)
@@ -56,7 +56,7 @@ void LanDeviceLink::reset(QSslSocket* socket, ConnectionStarted connectionSource
 
     m_connectionSource = connectionSource;
 
-    QString certString = KdeConnectConfig::instance()->getDeviceProperty(deviceId(), QStringLiteral("certificate"));
+    QString certString = KdeConnectConfig::instance().getDeviceProperty(deviceId(), QStringLiteral("certificate"));
     DeviceLink::setPairStatus(certString.isEmpty()? PairStatus::NotPaired : PairStatus::Paired);
 }
 
@@ -84,23 +84,32 @@ QString LanDeviceLink::name()
 
 bool LanDeviceLink::sendPacket(NetworkPacket& np)
 {
-    if (np.hasPayload()) {
-        np.setPayloadTransferInfo(sendPayload(np)->transferInfo());
+    if (np.payload()) {
+        if (np.type() == PACKET_TYPE_SHARE_REQUEST && np.payloadSize() >= 0) {
+            if (!m_compositeUploadJob || !m_compositeUploadJob->isRunning()) {
+                m_compositeUploadJob = new CompositeUploadJob(deviceId(), true);
+            }
+
+            m_compositeUploadJob->addSubjob(new UploadJob(np));
+
+            if (!m_compositeUploadJob->isRunning()) {
+                m_compositeUploadJob->start();
+            }
+        } else { //Infinite stream
+            CompositeUploadJob* fireAndForgetJob = new CompositeUploadJob(deviceId(), false);
+            fireAndForgetJob->addSubjob(new UploadJob(np));
+            fireAndForgetJob->start();
+        }
+
+        return true;
+    } else {
+        int written = m_socketLineReader->write(np.serialize());
+
+        //Actually we can't detect if a packet is received or not. We keep TCP
+        //"ESTABLISHED" connections that look legit (return true when we use them),
+        //but that are actually broken (until keepalive detects that they are down).
+        return (written != -1);
     }
-
-    int written = m_socketLineReader->write(np.serialize());
-
-    //Actually we can't detect if a packet is received or not. We keep TCP
-    //"ESTABLISHED" connections that look legit (return true when we use them),
-    //but that are actually broken (until keepalive detects that they are down).
-    return (written != -1);
-}
-
-UploadJob* LanDeviceLink::sendPayload(const NetworkPacket& np)
-{
-    UploadJob* job = new UploadJob(np.payload(), deviceId());
-    job->start();
-    return job;
 }
 
 void LanDeviceLink::dataReceived()
@@ -108,7 +117,7 @@ void LanDeviceLink::dataReceived()
     if (m_socketLineReader->bytesAvailable() == 0) return;
 
     const QByteArray serializedPacket = m_socketLineReader->readLine();
-    NetworkPacket packet(QString::null);
+    NetworkPacket packet((QString()));
     NetworkPacket::unserialize(serializedPacket, &packet);
 
     //qCDebug(KDECONNECT_CORE) << "LanDeviceLink dataReceived" << serializedPacket;
@@ -121,13 +130,20 @@ void LanDeviceLink::dataReceived()
 
     if (packet.hasPayloadTransferInfo()) {
         //qCDebug(KDECONNECT_CORE) << "HasPayloadTransferInfo";
-        QVariantMap transferInfo = packet.payloadTransferInfo();
-        //FIXME: The next two lines shouldn't be needed! Why are they here?
-        transferInfo.insert(QStringLiteral("useSsl"), true);
-        transferInfo.insert(QStringLiteral("deviceId"), deviceId());
-        DownloadJob* job = new DownloadJob(m_socketLineReader->peerAddress(), transferInfo);
-        job->start();
-        packet.setPayload(job->getPayload(), packet.payloadSize());
+        const QVariantMap transferInfo = packet.payloadTransferInfo();
+
+        QSharedPointer<QSslSocket> socket(new QSslSocket);
+
+        LanLinkProvider::configureSslSocket(socket.data(), deviceId(), true);
+
+        // emit readChannelFinished when the socket gets disconnected. This seems to be a bug in upstream QSslSocket.
+        // Needs investigation and upstreaming of the fix. QTBUG-62257
+        connect(socket.data(), &QAbstractSocket::disconnected, socket.data(), &QAbstractSocket::readChannelFinished);
+
+        const QString address = m_socketLineReader->peerAddress().toString();
+        const quint16 port = transferInfo[QStringLiteral("port")].toInt();
+        socket->connectToHostEncrypted(address, port, QIODevice::ReadWrite);
+        packet.setPayload(socket, packet.payloadSize());
     }
 
     Q_EMIT receivedPacket(packet);
@@ -161,9 +177,9 @@ void LanDeviceLink::setPairStatus(PairStatus status)
 
     DeviceLink::setPairStatus(status);
     if (status == Paired) {
-        Q_ASSERT(KdeConnectConfig::instance()->trustedDevices().contains(deviceId()));
+        Q_ASSERT(KdeConnectConfig::instance().trustedDevices().contains(deviceId()));
         Q_ASSERT(!m_socketLineReader->peerCertificate().isNull());
-        KdeConnectConfig::instance()->setDeviceProperty(deviceId(), QStringLiteral("certificate"), m_socketLineReader->peerCertificate().toPem());
+        KdeConnectConfig::instance().setDeviceProperty(deviceId(), QStringLiteral("certificate"), QString::fromLatin1(m_socketLineReader->peerCertificate().toPem().data()));
     }
 }
 
