@@ -15,13 +15,14 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LANDEVICELINK_H
 #define LANDEVICELINK_H
 
 #include <QObject>
+#include <QPointer>
 #include <QString>
 #include <QSslSocket>
 #include <QSslCertificate>
@@ -29,6 +30,7 @@
 #include <kdeconnectcore_export.h>
 #include "backends/devicelink.h"
 #include "uploadjob.h"
+#include "compositeuploadjob.h"
 
 class SocketLineReader;
 
@@ -45,7 +47,6 @@ public:
 
     QString name() override;
     bool sendPacket(NetworkPacket& np) override;
-    UploadJob* sendPayload(const NetworkPacket& np);
 
     void userRequestsPair() override;
     void userRequestsUnpair() override;
@@ -63,6 +64,7 @@ private:
     SocketLineReader* m_socketLineReader;
     ConnectionStarted m_connectionSource;
     QHostAddress m_hostAddress;
+    QPointer<CompositeUploadJob> m_compositeUploadJob;
 };
 
 #endif
