@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "lanlinkprovider.h"
@@ -30,6 +30,7 @@
 
 #include <QHostInfo>
 #include <QTcpServer>
+#include <QMetaEnum>
 #include <QNetworkProxy>
 #include <QUdpSocket>
 #include <QNetworkSession>
@@ -44,24 +45,32 @@
 
 #define MIN_VERSION_WITH_SSL_SUPPORT 6
 
-LanLinkProvider::LanLinkProvider(bool testMode)
-    : m_testMode(testMode)
+LanLinkProvider::LanLinkProvider(
+        bool testMode,
+        quint16 udpBroadcastPort,
+        quint16 udpListenPort
+    )
+    : m_server(new Server(this))
+    , m_udpSocket(this)
+    , m_tcpPort(0)
+    , m_udpBroadcastPort(udpBroadcastPort)
+    , m_udpListenPort(udpListenPort)
+    , m_testMode(testMode)
+    , m_combineBroadcastsTimer(this)
 {
-    m_tcpPort = 0;
 
     m_combineBroadcastsTimer.setInterval(0); // increase this if waiting a single event-loop iteration is not enough
     m_combineBroadcastsTimer.setSingleShot(true);
     connect(&m_combineBroadcastsTimer, &QTimer::timeout, this, &LanLinkProvider::broadcastToNetwork);
 
-    connect(&m_udpSocket, &QIODevice::readyRead, this, &LanLinkProvider::newUdpConnection);
+    connect(&m_udpSocket, &QIODevice::readyRead, this, &LanLinkProvider::udpBroadcastReceived);
 
-    m_server = new Server(this);
     m_server->setProxy(QNetworkProxy::NoProxy);
-    connect(m_server,&QTcpServer::newConnection,this, &LanLinkProvider::newConnection);
+    connect(m_server, &QTcpServer::newConnection, this, &LanLinkProvider::newConnection);
 
     m_udpSocket.setProxy(QNetworkProxy::NoProxy);
 
-    //Detect when a network interface changes status, so we announce ourelves in the new network
+    //Detect when a network interface changes status, so we announce ourselves in the new network
     QNetworkConfigurationManager* networkManager = new QNetworkConfigurationManager(this);
     connect(networkManager, &QNetworkConfigurationManager::configurationChanged, this, &LanLinkProvider::onNetworkConfigurationChanged);
 
@@ -83,11 +92,19 @@ void LanLinkProvider::onStart()
 {
     const QHostAddress bindAddress = m_testMode? QHostAddress::LocalHost : QHostAddress::Any;
 
-    bool success = m_udpSocket.bind(bindAddress, UDP_PORT, QUdpSocket::ShareAddress);
+    bool success = m_udpSocket.bind(bindAddress, m_udpListenPort, QUdpSocket::ShareAddress);
+    if (!success) {
+        QAbstractSocket::SocketError sockErr = m_udpSocket.error();
+        // Refer to https://doc.qt.io/qt-5/qabstractsocket.html#SocketError-enum to decode socket error number
+        QString errorMessage = QString::fromLatin1(QMetaEnum::fromType<QAbstractSocket::SocketError>().valueToKey(sockErr));
+        qCritical(KDECONNECT_CORE)
+            << QLatin1String("Failed to bind UDP socket on port")
+            << m_udpListenPort
+            << QLatin1String("with error")
+            << errorMessage;
+    }
     Q_ASSERT(success);
 
-    qCDebug(KDECONNECT_CORE) << "onStart";
-
     m_tcpPort = MIN_TCP_PORT;
     while (!m_server->listen(bindAddress, m_tcpPort)) {
         m_tcpPort++;
@@ -99,13 +116,14 @@ void LanLinkProvider::onStart()
     }
 
     onNetworkChange();
+    qCDebug(KDECONNECT_CORE) << "LanLinkProvider started";
 }
 
 void LanLinkProvider::onStop()
 {
-    qCDebug(KDECONNECT_CORE) << "onStop";
     m_udpSocket.close();
     m_server->close();
+    qCDebug(KDECONNECT_CORE) << "LanLinkProvider stopped";
 }
 
 void LanLinkProvider::onNetworkChange()
@@ -148,22 +166,21 @@ void LanLinkProvider::broadcastToNetwork()
                 QHostAddress sourceAddress = ifaceAddress.ip();
                 if (sourceAddress.protocol() == QAbstractSocket::IPv4Protocol && sourceAddress != QHostAddress::LocalHost) {
                     qCDebug(KDECONNECT_CORE()) << "Broadcasting as" << sourceAddress;
-                    sendSocket.bind(sourceAddress, UDP_PORT);
-                    sendSocket.writeDatagram(np.serialize(), destAddress, UDP_PORT);
+                    sendSocket.writeDatagram(np.serialize(), destAddress, m_udpBroadcastPort);
                     sendSocket.close();
                 }
             }
         }
     }
 #else
-    m_udpSocket.writeDatagram(np.serialize(), destAddress, UDP_PORT);
+    m_udpSocket.writeDatagram(np.serialize(), destAddress, m_udpBroadcastPort);
 #endif
 
 }
 
 //I'm the existing device, a new device is kindly introducing itself.
-//I will create a TcpSocket and try to connect. This can result in either connected() or connectError().
-void LanLinkProvider::newUdpConnection() //udpBroadcastReceived
+//I will create a TcpSocket and try to connect. This can result in either tcpSocketConnected() or connectError().
+void LanLinkProvider::udpBroadcastReceived()
 {
     while (m_udpSocket.hasPendingDatagrams()) {
 
@@ -183,12 +200,19 @@ void LanLinkProvider::newUdpConnection() //udpBroadcastReceived
 
         //qCDebug(KDECONNECT_CORE) << "Datagram " << datagram.data() ;
 
-        if (!success || receivedPacket->type() != PACKET_TYPE_IDENTITY) {
+        if (!success) {
+            qCDebug(KDECONNECT_CORE) << "Could not unserialize UDP packet";
             delete receivedPacket;
             continue;
         }
 
-        if (receivedPacket->get<QString>(QStringLiteral("deviceId")) == KdeConnectConfig::instance()->deviceId()) {
+        if (receivedPacket->type() != PACKET_TYPE_IDENTITY) {
+            qCDebug(KDECONNECT_CORE) << "Received a UDP packet of wrong type" << receivedPacket->type();
+            delete receivedPacket;
+            continue;
+        }
+
+        if (receivedPacket->get<QString>(QStringLiteral("deviceId")) == KdeConnectConfig::instance().deviceId()) {
             //qCDebug(KDECONNECT_CORE) << "Ignoring my own broadcast";
             delete receivedPacket;
             continue;
@@ -202,24 +226,23 @@ void LanLinkProvider::newUdpConnection() //udpBroadcastReceived
         socket->setProxy(QNetworkProxy::NoProxy);
         m_receivedIdentityPackets[socket].np = receivedPacket;
         m_receivedIdentityPackets[socket].sender = sender;
-        connect(socket, &QAbstractSocket::connected, this, &LanLinkProvider::connected);
-        connect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(connectError()));
+        connect(socket, &QAbstractSocket::connected, this, &LanLinkProvider::tcpSocketConnected);
+        connect(socket, QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::error), this, &LanLinkProvider::connectError);
         socket->connectToHost(sender, tcpPort);
     }
 }
 
-void LanLinkProvider::connectError()
+void LanLinkProvider::connectError(QAbstractSocket::SocketError socketError)
 {
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
     if (!socket) return;
-    disconnect(socket, &QAbstractSocket::connected, this, &LanLinkProvider::connected);
-    disconnect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(connectError()));
 
+    qCDebug(KDECONNECT_CORE) << "Socket error" << socketError;
     qCDebug(KDECONNECT_CORE) << "Fallback (1), try reverse connection (send udp packet)" << socket->errorString();
     NetworkPacket np(QLatin1String(""));
     NetworkPacket::createIdentityPacket(&np);
     np.set(QStringLiteral("tcpPort"), m_tcpPort);
-    m_udpSocket.writeDatagram(np.serialize(), m_receivedIdentityPackets[socket].sender, UDP_PORT);
+    m_udpSocket.writeDatagram(np.serialize(), m_receivedIdentityPackets[socket].sender, m_udpBroadcastPort);
 
     //The socket we created didn't work, and we didn't manage
     //to create a LanDeviceLink from it, deleting everything.
@@ -227,14 +250,14 @@ void LanLinkProvider::connectError()
     delete socket;
 }
 
-//We received a UDP packet and answered by connecting to them by TCP. This gets called on a succesful connection.
-void LanLinkProvider::connected()
+//We received a UDP packet and answered by connecting to them by TCP. This gets called on a successful connection.
+void LanLinkProvider::tcpSocketConnected()
 {
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
 
     if (!socket) return;
-    disconnect(socket, &QAbstractSocket::connected, this, &LanLinkProvider::connected);
-    disconnect(socket, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(connectError()));
+    // TODO Delete me?
+    disconnect(socket, QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::error), this, &LanLinkProvider::connectError);
 
     configureSocket(socket);
 
@@ -243,7 +266,7 @@ void LanLinkProvider::connected()
 
     NetworkPacket* receivedPacket = m_receivedIdentityPackets[socket].np;
     const QString& deviceId = receivedPacket->get<QString>(QStringLiteral("deviceId"));
-    //qCDebug(KDECONNECT_CORE) << "Connected" << socket->isWritable();
+    //qCDebug(KDECONNECT_CORE) << "tcpSocketConnected" << socket->isWritable();
 
     // If network is on ssl, do not believe when they are connected, believe when handshake is completed
     NetworkPacket np2(QLatin1String(""));
@@ -258,7 +281,7 @@ void LanLinkProvider::connected()
         // if ssl supported
         if (receivedPacket->get<int>(QStringLiteral("protocolVersion")) >= MIN_VERSION_WITH_SSL_SUPPORT) {
 
-            bool isDeviceTrusted = KdeConnectConfig::instance()->trustedDevices().contains(deviceId);
+            bool isDeviceTrusted = KdeConnectConfig::instance().trustedDevices().contains(deviceId);
             configureSslSocket(socket, deviceId, isDeviceTrusted);
 
             qCDebug(KDECONNECT_CORE) << "Starting server ssl (I'm the client TCP socket)";
@@ -266,7 +289,7 @@ void LanLinkProvider::connected()
             connect(socket, &QSslSocket::encrypted, this, &LanLinkProvider::encrypted);
 
             if (isDeviceTrusted) {
-                connect(socket, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrors(QList<QSslError>)));
+                connect(socket, QOverload<const QList<QSslError> &>::of(&QSslSocket::sslErrors), this, &LanLinkProvider::sslErrors);
             }
 
             socket->startServerEncryption();
@@ -281,7 +304,7 @@ void LanLinkProvider::connected()
         //I think this will never happen, but if it happens the deviceLink
         //(or the socket that is now inside it) might not be valid. Delete them.
         qCDebug(KDECONNECT_CORE) << "Fallback (2), try reverse connection (send udp packet)";
-        m_udpSocket.writeDatagram(np2.serialize(), m_receivedIdentityPackets[socket].sender, UDP_PORT);
+        m_udpSocket.writeDatagram(np2.serialize(), m_receivedIdentityPackets[socket].sender, m_udpBroadcastPort);
     }
 
     delete m_receivedIdentityPackets.take(socket).np;
@@ -290,12 +313,12 @@ void LanLinkProvider::connected()
 
 void LanLinkProvider::encrypted()
 {
-    qCDebug(KDECONNECT_CORE) << "Socket succesfully stablished an SSL connection";
+    qCDebug(KDECONNECT_CORE) << "Socket successfully established an SSL connection";
 
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
     if (!socket) return;
-    disconnect(socket, &QSslSocket::encrypted, this, &LanLinkProvider::encrypted);
-    disconnect(socket, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrors(QList<QSslError>)));
+    // TODO delete me?
+    disconnect(socket, QOverload<const QList<QSslError> &>::of(&QSslSocket::sslErrors), this, &LanLinkProvider::sslErrors);
 
     Q_ASSERT(socket->mode() != QSslSocket::UnencryptedMode);
     LanDeviceLink::ConnectionStarted connectionOrigin = (socket->mode() == QSslSocket::SslClientMode)? LanDeviceLink::Locally : LanDeviceLink::Remotely;
@@ -305,7 +328,7 @@ void LanLinkProvider::encrypted()
 
     addLink(deviceId, socket, receivedPacket, connectionOrigin);
 
-    // Copied from connected slot, now delete received packet
+    // Copied from tcpSocketConnected slot, now delete received packet
     delete m_receivedIdentityPackets.take(socket).np;
 }
 
@@ -314,9 +337,6 @@ void LanLinkProvider::sslErrors(const QList<QSslError>& errors)
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
     if (!socket) return;
 
-    disconnect(socket, &QSslSocket::encrypted, this, &LanLinkProvider::encrypted);
-    disconnect(socket, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrors(QList<QSslError>)));
-
     qCDebug(KDECONNECT_CORE) << "Failing due to " << errors;
     Device* device = Daemon::instance()->getDevice(socket->peerVerifyName());
     if (device) {
@@ -330,7 +350,7 @@ void LanLinkProvider::sslErrors(const QList<QSslError>& errors)
 //I'm the new device and this is the answer to my UDP identity packet (no data received yet). They are connecting to us through TCP, and they should send an identity.
 void LanLinkProvider::newConnection()
 {
-    //qCDebug(KDECONNECT_CORE) << "LanLinkProvider newConnection";
+    qCDebug(KDECONNECT_CORE) << "LanLinkProvider newConnection";
 
     while (m_server->hasPendingConnections()) {
         QSslSocket* socket = m_server->nextPendingConnection();
@@ -350,18 +370,21 @@ void LanLinkProvider::newConnection()
 void LanLinkProvider::dataReceived()
 {
     QSslSocket* socket = qobject_cast<QSslSocket*>(sender());
+    socket->startTransaction();
 
     const QByteArray data = socket->readLine();
 
-    //qCDebug(KDECONNECT_CORE) << "LanLinkProvider received reply:" << data;
+    qCDebug(KDECONNECT_CORE) << "LanLinkProvider received reply:" << data;
 
     NetworkPacket* np = new NetworkPacket(QLatin1String(""));
     bool success = NetworkPacket::unserialize(data, np);
 
     if (!success) {
         delete np;
+        socket->rollbackTransaction();
         return;
     }
+    socket->commitTransaction();
 
     if (np->type() != PACKET_TYPE_IDENTITY) {
         qCWarning(KDECONNECT_CORE) << "LanLinkProvider/newConnection: Expected identity, received " << np->type();
@@ -369,7 +392,7 @@ void LanLinkProvider::dataReceived()
         return;
     }
 
-    // Needed in "encrypted" if ssl is used, similar to "connected"
+    // Needed in "encrypted" if ssl is used, similar to "tcpSocketConnected"
     m_receivedIdentityPackets[socket].np = np;
 
     const QString& deviceId = np->get<QString>(QStringLiteral("deviceId"));
@@ -380,7 +403,7 @@ void LanLinkProvider::dataReceived()
 
     if (np->get<int>(QStringLiteral("protocolVersion")) >= MIN_VERSION_WITH_SSL_SUPPORT) {
 
-        bool isDeviceTrusted = KdeConnectConfig::instance()->trustedDevices().contains(deviceId);
+        bool isDeviceTrusted = KdeConnectConfig::instance().trustedDevices().contains(deviceId);
         configureSslSocket(socket, deviceId, isDeviceTrusted);
 
         qCDebug(KDECONNECT_CORE) << "Starting client ssl (but I'm the server TCP socket)";
@@ -388,7 +411,7 @@ void LanLinkProvider::dataReceived()
         connect(socket, &QSslSocket::encrypted, this, &LanLinkProvider::encrypted);
 
         if (isDeviceTrusted) {
-            connect(socket, SIGNAL(sslErrors(QList<QSslError>)), this, SLOT(sslErrors(QList<QSslError>)));
+            connect(socket, QOverload<const QList<QSslError> &>::of(&QSslSocket::sslErrors), this, &LanLinkProvider::sslErrors);
         }
 
         socket->startClientEncryption();
@@ -419,29 +442,23 @@ void LanLinkProvider::deviceLinkDestroyed(QObject* destroyedDeviceLink)
 
 void LanLinkProvider::configureSslSocket(QSslSocket* socket, const QString& deviceId, bool isDeviceTrusted)
 {
-    // Setting supported ciphers manually
-    // Top 3 ciphers are for new Android devices, botton two are for old Android devices
-    // FIXME : These cipher suites should be checked whether they are supported or not on device
+    // Setting supported ciphers manually, to match those on Android (FIXME: Test if this can be left unconfigured and still works for Android 4)
     QList<QSslCipher> socketCiphers;
     socketCiphers.append(QSslCipher(QStringLiteral("ECDHE-ECDSA-AES256-GCM-SHA384")));
     socketCiphers.append(QSslCipher(QStringLiteral("ECDHE-ECDSA-AES128-GCM-SHA256")));
     socketCiphers.append(QSslCipher(QStringLiteral("ECDHE-RSA-AES128-SHA")));
-    socketCiphers.append(QSslCipher(QStringLiteral("RC4-SHA")));
-    socketCiphers.append(QSslCipher(QStringLiteral("RC4-MD5")));
-    socketCiphers.append(QSslCipher(QStringLiteral("DHE-RSA-AES256-SHA")));
 
     // Configure for ssl
     QSslConfiguration sslConfig;
     sslConfig.setCiphers(socketCiphers);
-    sslConfig.setProtocol(QSsl::TlsV1_0);
 
     socket->setSslConfiguration(sslConfig);
-    socket->setLocalCertificate(KdeConnectConfig::instance()->certificate());
-    socket->setPrivateKey(KdeConnectConfig::instance()->privateKeyPath());
+    socket->setLocalCertificate(KdeConnectConfig::instance().certificate());
+    socket->setPrivateKey(KdeConnectConfig::instance().privateKeyPath());
     socket->setPeerVerifyName(deviceId);
 
     if (isDeviceTrusted) {
-        QString certString = KdeConnectConfig::instance()->getDeviceProperty(deviceId, QStringLiteral("certificate"), QString());
+        QString certString = KdeConnectConfig::instance().getDeviceProperty(deviceId, QStringLiteral("certificate"), QString());
         socket->addCaCertificate(QSslCertificate(certString.toLatin1()));
         socket->setPeerVerifyMode(QSslSocket::VerifyPeer);
     } else {
