@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LANLINKPROVIDER_H
@@ -27,7 +27,6 @@
 #include <QUdpSocket>
 #include <QTimer>
 #include <QNetworkSession>
-#include <QSslSocket>
 
 #include "kdeconnectcore_export.h"
 #include "backends/linkprovider.h"
@@ -41,7 +40,16 @@ class KDECONNECTCORE_EXPORT LanLinkProvider
     Q_OBJECT
 
 public:
-    LanLinkProvider(bool testMode = false);
+    /**
+     * @param testMode Some special overrides needed while testing
+     * @param udpBroadcastPort Port which should be used for *sending* identity packets
+     * @param udpListenPort Port which should be used for *receiving* identity packets
+     */
+    LanLinkProvider(
+            bool testMode = false,
+            quint16 udpBroadcastPort = UDP_PORT,
+            quint16 udpListenPort = UDP_PORT
+            );
     ~LanLinkProvider() override;
 
     QString name() override { return QStringLiteral("LanLinkProvider"); }
@@ -54,6 +62,9 @@ public:
     static void configureSslSocket(QSslSocket* socket, const QString& deviceId, bool isDeviceTrusted);
     static void configureSocket(QSslSocket* socket);
 
+    /**
+     * This is the default UDP port both for broadcasting and receiving identity packets
+     */
     const static quint16 UDP_PORT = 1716;
     const static quint16 MIN_TCP_PORT = 1716;
     const static quint16 MAX_TCP_PORT = 1764;
@@ -62,12 +73,12 @@ public Q_SLOTS:
     void onNetworkChange() override;
     void onStart() override;
     void onStop() override;
-    void connected();
+    void tcpSocketConnected();
     void encrypted();
     void connectError(QAbstractSocket::SocketError socketError);
 
 private Q_SLOTS:
-    void newUdpConnection();
+    void udpBroadcastReceived();
     void newConnection();
     void dataReceived();
     void deviceLinkDestroyed(QObject* destroyedDeviceLink);
@@ -84,6 +95,9 @@ private:
     QUdpSocket m_udpSocket;
     quint16 m_tcpPort;
 
+    quint16 m_udpBroadcastPort;
+    quint16 m_udpListenPort;
+
     QMap<QString, LanDeviceLink*> m_links;
     QMap<QString, LanPairingHandler*> m_pairingHandlers;
 
