@@ -15,12 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "daemon.h"
 
-#include <QDBusConnection>
 #include <QDBusMetaType>
 #include <QNetworkAccessManager>
 #include <QDebug>
@@ -29,6 +28,8 @@
 #include "core_debug.h"
 #include "kdeconnectconfig.h"
 #include "networkpacket.h"
+#include "dbushelper.h"
+#include "notificationserverinfo.h"
 
 #ifdef KDECONNECT_BLUETOOTH
     #include "backends/bluetooth/bluetoothlinkprovider.h"
@@ -40,6 +41,9 @@
 #include "backends/devicelink.h"
 #include "backends/linkprovider.h"
 
+//In older Qt released, qAsConst isnt available
+#include "qtcompat_p.h"
+
 static Daemon* s_instance = nullptr;
 
 struct DaemonPrivate
@@ -51,6 +55,7 @@ struct DaemonPrivate
     QMap<QString, Device*> m_devices;
 
     QSet<QString> m_discoveryModeAcquisitions;
+    bool m_testMode;
 };
 
 Daemon* Daemon::instance()
@@ -65,20 +70,31 @@ Daemon::Daemon(QObject* parent, bool testMode)
 {
     Q_ASSERT(!s_instance);
     s_instance = this;
-    qCDebug(KDECONNECT_CORE) << "KdeConnect daemon starting";
+    d->m_testMode = testMode;
+
+    // HACK init may call pure virtual functions from this class so it can't be called directly from the ctor
+    QTimer::singleShot(0, this, &Daemon::init);
+}
+
+void Daemon::init()
+{
+    qCDebug(KDECONNECT_CORE) << "Daemon starting";
 
     //Load backends
-    if (testMode)
+    if (d->m_testMode)
         d->m_linkProviders.insert(new LoopbackLinkProvider());
     else {
         d->m_linkProviders.insert(new LanLinkProvider());
         #ifdef KDECONNECT_BLUETOOTH
             d->m_linkProviders.insert(new BluetoothLinkProvider());
         #endif
+        #ifdef KDECONNECT_LOOPBACK
+            d->m_linkProviders.insert(new LoopbackLinkProvider());
+        #endif
     }
 
-    //Read remebered paired devices
-    const QStringList& list = KdeConnectConfig::instance()->trustedDevices();
+    //Read remembered paired devices
+    const QStringList& list = KdeConnectConfig::instance().trustedDevices();
     for (const QString& id : list) {
         addDevice(new Device(this, id));
     }
@@ -92,10 +108,12 @@ Daemon::Daemon(QObject* parent, bool testMode)
 
     //Register on DBus
     qDBusRegisterMetaType< QMap<QString,QString> >();
-    QDBusConnection::sessionBus().registerService(QStringLiteral("org.kde.kdeconnect"));
-    QDBusConnection::sessionBus().registerObject(QStringLiteral("/modules/kdeconnect"), this, QDBusConnection::ExportScriptableContents);
+    DBusHelper::sessionBus().registerService(QStringLiteral("org.kde.kdeconnect"));
+    DBusHelper::sessionBus().registerObject(QStringLiteral("/modules/kdeconnect"), this, QDBusConnection::ExportScriptableContents);
 
-    qCDebug(KDECONNECT_CORE) << "KdeConnect daemon started";
+    NotificationServerInfo::instance().init();
+
+    qCDebug(KDECONNECT_CORE) << "Daemon started";
 }
 
 void Daemon::acquireDiscoveryMode(const QString& key)
@@ -145,7 +163,7 @@ void Daemon::cleanDevices()
 
 void Daemon::forceOnNetworkChange()
 {
-    qCDebug(KDECONNECT_CORE) << "Sending onNetworkChange to " << d->m_linkProviders.size() << " LinkProviders";
+    qCDebug(KDECONNECT_CORE) << "Sending onNetworkChange to" << d->m_linkProviders.size() << "LinkProviders";
     for (LinkProvider* a : qAsConst(d->m_linkProviders)) {
         a->onNetworkChange();
     }
@@ -158,7 +176,12 @@ Device*Daemon::getDevice(const QString& deviceId)
             return device;
         }
     }
-    return Q_NULLPTR;
+    return nullptr;
+}
+
+const QSet<LinkProvider*>& Daemon::getLinkProviders() const
+{
+    return d->m_linkProviders;
 }
 
 QStringList Daemon::devices(bool onlyReachable, bool onlyTrusted) const
@@ -230,14 +253,14 @@ void Daemon::onDeviceStatusChanged()
 void Daemon::setAnnouncedName(const QString& name)
 {
     qCDebug(KDECONNECT_CORE()) << "Announcing name";
-    KdeConnectConfig::instance()->setName(name);
+    KdeConnectConfig::instance().setName(name);
     forceOnNetworkChange();
     Q_EMIT announcedNameChanged(name);
 }
 
 QString Daemon::announcedName()
 {
-    return KdeConnectConfig::instance()->name();
+    return KdeConnectConfig::instance().name();
 }
 
 QNetworkAccessManager* Daemon::networkAccessManager()
@@ -287,7 +310,7 @@ void Daemon::addDevice(Device* device)
 QStringList Daemon::pairingRequests() const
 {
     QStringList ret;
-    for(Device* dev: d->m_devices) {
+    for(Device* dev: qAsConst(d->m_devices)) {
         if (dev->hasPairingRequests())
             ret += dev->id();
     }
@@ -301,5 +324,5 @@ Daemon::~Daemon()
 
 QString Daemon::selfId() const
 {
-    return KdeConnectConfig::instance()->deviceId();
+    return KdeConnectConfig::instance().deviceId();
 }
