@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KDECONNECT_DAEMON_H
@@ -32,6 +32,7 @@ class NetworkPacket;
 class DeviceLink;
 class Device;
 class QNetworkAccessManager;
+class KJobTrackerInterface;
 
 class KDECONNECTCORE_EXPORT Daemon
     : public QObject
@@ -51,10 +52,14 @@ public:
 
     virtual void askPairingConfirmation(Device* device) = 0;
     virtual void reportError(const QString& title, const QString& description) = 0;
+    virtual void quit() = 0;
     virtual QNetworkAccessManager* networkAccessManager();
+    virtual KJobTrackerInterface* jobTracker() = 0;
 
     Device* getDevice(const QString& deviceId);
 
+    const QSet<LinkProvider*>& getLinkProviders() const;
+
     QStringList pairingRequests() const;
 
     Q_SCRIPTABLE QString selfId() const;
@@ -90,6 +95,9 @@ private Q_SLOTS:
     void onDeviceStatusChanged();
 
 private:
+    void init();
+
+protected:
     void addDevice(Device* device);
     bool isDiscoveringDevices() const;
     void removeDevice(Device* d);
