@@ -16,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "filetransferjob.h"
@@ -29,25 +29,27 @@
 
 #include <KLocalizedString>
 
-FileTransferJob::FileTransferJob(const QSharedPointer<QIODevice>& origin, qint64 size, const QUrl& destination)
+FileTransferJob::FileTransferJob(const NetworkPacket* np, const QUrl& destination)
     : KJob()
-    , m_origin(origin)
-    , m_reply(Q_NULLPTR)
+    , m_origin(np->payload())
+    , m_reply(nullptr)
     , m_from(QStringLiteral("KDE Connect"))
     , m_destination(destination)
     , m_speedBytes(0)
     , m_written(0)
-    , m_size(size)
+    , m_size(np->payloadSize())
+    , m_np(np)
 {
     Q_ASSERT(m_origin);
-    Q_ASSERT(m_origin->isReadable());
+    //Disabled this assert: QBluetoothSocket doesn't report "->isReadable() == true" until it's connected
+    //Q_ASSERT(m_origin->isReadable());
     if (m_destination.scheme().isEmpty()) {
         qCWarning(KDECONNECT_CORE) << "Destination QUrl" << m_destination << "lacks a scheme. Setting its scheme to 'file'.";
         m_destination.setScheme(QStringLiteral("file"));
     }
 
     setCapabilities(Killable);
-    qCDebug(KDECONNECT_CORE) << "FileTransferJob Downloading payload to" << destination << "size:" << size;
+    qCDebug(KDECONNECT_CORE) << "FileTransferJob Downloading payload to" << destination << "size:" << m_size;
 }
 
 void FileTransferJob::start()
@@ -58,10 +60,6 @@ void FileTransferJob::start()
 
 void FileTransferJob::doStart()
 {
-    description(this, i18n("Receiving file over KDE Connect"),
-        { i18nc("File transfer origin", "From"), m_from }
-    );
-
     if (m_destination.isLocalFile() && QFile::exists(m_destination.toLocalFile())) {
         setError(2);
         setErrorText(i18n("Filename already present"));
@@ -81,9 +79,6 @@ void FileTransferJob::startTransfer()
         return;
 
     setProcessedAmount(Bytes, 0);
-    description(this, i18n("Receiving file over KDE Connect"),
-                        { i18nc("File transfer origin", "From"), m_from },
-                        { i18nc("File transfer destination", "To"), m_destination.toLocalFile() });
 
     QNetworkRequest req(m_destination);
     if (m_size >= 0) {
@@ -101,6 +96,8 @@ void FileTransferJob::startTransfer()
         if (elapsed > 0) {
             emitSpeed((1000 * bytesSent) / elapsed);
         }
+        
+        m_written = bytesSent;
     });
     connect(m_reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error),
             this, &FileTransferJob::transferFailed);
@@ -120,9 +117,25 @@ void FileTransferJob::transferFailed(QNetworkReply::NetworkError error)
 void FileTransferJob::transferFinished()
 {
     //TODO: MD5-check the file
-    qCDebug(KDECONNECT_CORE) << "Finished transfer" << m_destination;
+    if (m_size == m_written) {
+        qCDebug(KDECONNECT_CORE) << "Finished transfer" << m_destination;
+        emitResult();
+    } else {
+        qCDebug(KDECONNECT_CORE) << "Received incomplete file ("<< m_written << "/" << m_size << "bytes ), deleting";
+        
+        deleteDestinationFile();
 
-    emitResult();
+        setError(3);
+        setErrorText(i18n("Received incomplete file from: %1", m_from));
+        emitResult();
+    }
+}
+
+void FileTransferJob::deleteDestinationFile()
+{
+    if (m_destination.isLocalFile() && QFile::exists(m_destination.toLocalFile())) {
+        QFile::remove(m_destination.toLocalFile());
+    }
 }
 
 bool FileTransferJob::doKill()
@@ -133,5 +146,8 @@ bool FileTransferJob::doKill()
     if (m_origin) {
         m_origin->close();
     }
+
+    deleteDestinationFile();
+
     return true;
 }
