@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KDECONNECTCONFIG_H
@@ -26,10 +26,6 @@
 #include "kdeconnectcore_export.h"
 
 class QSslCertificate;
-namespace QCA {
-    class PrivateKey;
-    class PublicKey;
-}
 
 class KDECONNECTCORE_EXPORT KdeConnectConfig
 {
@@ -39,7 +35,7 @@ public:
         QString deviceType;
     };
 
-    static KdeConnectConfig* instance();
+    static KdeConnectConfig& instance();
 
     /*
      * Our own info
@@ -50,9 +46,6 @@ public:
     QString deviceType();
 
     QString privateKeyPath();
-    QCA::PrivateKey privateKey();
-    QCA::PublicKey publicKey();
-
     QString certificatePath();
     QSslCertificate certificate();
 
@@ -77,10 +70,20 @@ public:
     QDir deviceConfigDir(const QString& deviceId);
     QDir pluginConfigDir(const QString& deviceId, const QString& pluginName); //Used by KdeConnectPluginConfig
 
+#ifdef USE_PRIVATE_DBUS
+    /*
+     * Get private DBus Address when use private DBus
+     */
+    QString privateDBusAddressPath();
+    QString privateDBusAddress();
+#endif
 private:
     KdeConnectConfig();
 
-private:
+    void loadPrivateKey();
+    void generatePrivateKey(const QString&  path);
+    void loadCertificate();
+    void generateCertificate(const QString&  path);
 
     struct KdeConnectConfigPrivate* d;
 };
