@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "kdeconnectplugin.h"
@@ -28,6 +28,7 @@ struct KdeConnectPluginPrivate
     QString m_pluginName;
     QSet<QString> m_outgoingCapabilties;
     KdeConnectPluginConfig* m_config;
+    QString iconName;
 };
 
 KdeConnectPlugin::KdeConnectPlugin(QObject* parent, const QVariantList& args)
@@ -38,6 +39,7 @@ KdeConnectPlugin::KdeConnectPlugin(QObject* parent, const QVariantList& args)
     d->m_pluginName = args.at(1).toString();
     d->m_outgoingCapabilties = args.at(2).toStringList().toSet();
     d->m_config = nullptr;
+    d->iconName = args.at(3).toString();
 }
 
 KdeConnectPluginConfig* KdeConnectPlugin::config() const
@@ -80,3 +82,8 @@ QString KdeConnectPlugin::dbusPath() const
 {
     return {};
 }
+
+QString KdeConnectPlugin::iconName() const
+{
+    return d->iconName;
+}
