@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "pluginloader.h"
@@ -28,6 +28,9 @@
 #include "device.h"
 #include "kdeconnectplugin.h"
 
+//In older Qt released, qAsConst isnt available
+#include "qtcompat_p.h"
+
 PluginLoader* PluginLoader::instance()
 {
     static PluginLoader* instance = new PluginLoader();
@@ -54,7 +57,7 @@ KPluginMetaData PluginLoader::getPluginInfo(const QString& name) const
 
 KdeConnectPlugin* PluginLoader::instantiatePluginForDevice(const QString& pluginName, Device* device) const
 {
-    KdeConnectPlugin* ret = Q_NULLPTR;
+    KdeConnectPlugin* ret = nullptr;
 
     KPluginMetaData service = plugins.value(pluginName);
     if (!service.isValid()) {
@@ -73,7 +76,7 @@ KdeConnectPlugin* PluginLoader::instantiatePluginForDevice(const QString& plugin
 
     QVariant deviceVariant = QVariant::fromValue<Device*>(device);
 
-    ret = factory->create<KdeConnectPlugin>(device, QVariantList() << deviceVariant << pluginName << outgoingInterfaces);
+    ret = factory->create<KdeConnectPlugin>(device, QVariantList() << deviceVariant << pluginName << outgoingInterfaces << service.iconName());
     if (!ret) {
         qCDebug(KDECONNECT_CORE) << "Error loading plugin";
         return ret;
