@@ -15,13 +15,17 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "deviceindicator.h"
 #include <QFileDialog>
 #include <KLocalizedString>
 
+#include "interfaces/dbusinterfaces.h"
+
+#include <dbushelper.h>
+
 class BatteryAction : public QAction
 {
 Q_OBJECT
@@ -36,6 +40,8 @@ public:
         connect(m_batteryIface, SIGNAL(chargeChanged(int)), this, SLOT(setCharge(int)));
         connect(m_batteryIface, SIGNAL(stateChanged(bool)), this, SLOT(setCharging(bool)));
 
+        setIcon(QIcon::fromTheme(QStringLiteral("battery")));
+
         update();
     }
 
@@ -62,9 +68,10 @@ private:
 DeviceIndicator::DeviceIndicator(DeviceDbusInterface* device)
     : QMenu(device->name(), nullptr)
     , m_device(device)
+    , m_remoteCommandsInterface(new RemoteCommandsDbusInterface(m_device->id()))
 {
 #ifdef Q_OS_WIN
-    setIcon(QIcon(QStandardPaths::locate(QStandardPaths::AppDataLocation, "icons/hicolor/scalable/status/"+device->iconName()+".svg")));
+    setIcon(QIcon(QStandardPaths::locate(QStandardPaths::AppDataLocation, QStringLiteral("icons/hicolor/scalable/status/") + device->iconName() + QStringLiteral(".svg"))));
 #else
     setIcon(QIcon::fromTheme(device->iconName()));
 #endif
@@ -73,37 +80,72 @@ DeviceIndicator::DeviceIndicator(DeviceDbusInterface* device)
 
     auto battery = new BatteryAction(device);
     addAction(battery);
-    setWhenAvailable(device->hasPlugin("kdeconnect_battery"),
+    setWhenAvailable(device->hasPlugin(QStringLiteral("kdeconnect_battery")),
                      [battery](bool available) { battery->setVisible(available);  }
                      , this);
 
-    auto browse = addAction(i18n("Browse device"));
+    auto browse = addAction(QIcon::fromTheme(QStringLiteral("document-open-folder")), i18n("Browse device"));
     connect(browse, &QAction::triggered, device, [device](){
         SftpDbusInterface* sftpIface = new SftpDbusInterface(device->id(), device);
         sftpIface->startBrowsing();
         sftpIface->deleteLater();
     });
-    setWhenAvailable(device->hasPlugin("kdeconnect_sftp"), [browse](bool available) { browse->setVisible(available); }, this);
+    setWhenAvailable(device->hasPlugin(QStringLiteral("kdeconnect_sftp")), [browse](bool available) { browse->setVisible(available); }, this);
 
-    auto findDevice = addAction(i18n("Ring device"));
+    auto findDevice = addAction(QIcon::fromTheme(QStringLiteral("irc-voice")), i18n("Ring device"));
     connect(findDevice, &QAction::triggered, device, [device](){
         FindMyPhoneDeviceDbusInterface* iface = new FindMyPhoneDeviceDbusInterface(device->id(), device);
         iface->ring();
         iface->deleteLater();
     });
-    setWhenAvailable(device->hasPlugin("kdeconnect_findmyphone"), [findDevice](bool available) { findDevice->setVisible(available); }, this);
+    setWhenAvailable(device->hasPlugin(QStringLiteral("kdeconnect_findmyphone")), [findDevice](bool available) { findDevice->setVisible(available); }, this);
 
-    auto sendFile = addAction(i18n("Send file"));
+    auto sendFile = addAction(QIcon::fromTheme(QStringLiteral("document-share")), i18n("Send file"));
     connect(sendFile, &QAction::triggered, device, [device, this](){
         const QUrl url = QFileDialog::getOpenFileUrl(parentWidget(), i18n("Select file to send to '%1'", device->name()), QUrl::fromLocalFile(QDir::homePath()));
         if (url.isEmpty())
             return;
 
-        QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), "/modules/kdeconnect/devices/"+device->id()+"/share", QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareUrl"));
+        QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect/devices/") + device->id() + QStringLiteral("/share"), QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareUrl"));
         msg.setArguments(QVariantList() << url.toString());
-        QDBusConnection::sessionBus().call(msg);
+        DBusHelper::sessionBus().call(msg);
     });
-    setWhenAvailable(device->hasPlugin("kdeconnect_share"), [sendFile](bool available) { sendFile->setVisible(available); }, this);
+
+    setWhenAvailable(device->hasPlugin(QStringLiteral("kdeconnect_share")), [sendFile](bool available) { sendFile->setVisible(available); }, this);
+
+    // Search current application path
+    const QString kdeconnectsmsExecutable = QStandardPaths::findExecutable(QStringLiteral("kdeconnect-sms"), { QCoreApplication::applicationDirPath() });
+    if (!kdeconnectsmsExecutable.isEmpty()) {
+        auto smsapp = addAction(QIcon::fromTheme(QStringLiteral("message-new")), i18n("SMS Messages..."));
+        QObject::connect(smsapp, &QAction::triggered, device, [device, kdeconnectsmsExecutable] () {
+            QProcess::startDetached(kdeconnectsmsExecutable, { QStringLiteral("--device"), device->id() });
+        });
+        setWhenAvailable(device->hasPlugin(QStringLiteral("kdeconnect_sms")), [smsapp](bool available) { smsapp->setVisible(available); }, this);
+    }
+
+    QMenu* remoteCommandsMenu = new QMenu(i18n("Run command"), this);
+    QAction* menuAction = remoteCommandsMenu->menuAction();
+    QAction* addCommandAction = remoteCommandsMenu->addAction(QIcon::fromTheme(QStringLiteral("list-add")), i18n("Add commands"));
+    connect(addCommandAction, &QAction::triggered, m_remoteCommandsInterface, &RemoteCommandsDbusInterface::editCommands);
+
+    addAction(menuAction);
+    setWhenAvailable(device->hasPlugin(QStringLiteral("kdeconnect_remotecommands")), [this, remoteCommandsMenu, menuAction](bool available) {
+        menuAction->setVisible(available);
+
+        if (!available)
+            return;
+
+        const auto cmds = QJsonDocument::fromJson(m_remoteCommandsInterface->commands()).object();
+
+        for (auto it = cmds.constBegin(), itEnd = cmds.constEnd(); it!=itEnd; ++it) {
+            const QJsonObject cont = it->toObject();
+            QString key = it.key();
+            QAction* action = remoteCommandsMenu->addAction(cont.value(QStringLiteral("name")).toString());
+            connect(action, &QAction::triggered, [this, key] {
+                m_remoteCommandsInterface->triggerCommand(key);
+            });
+        }
+    }, this);
 }
 
 #include "deviceindicator.moc"
