@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "notificationsmodel.h"
@@ -24,11 +24,15 @@
 #include <QDebug>
 #include <QDBusInterface>
 
-#include <KSharedConfig>
 #include <QIcon>
 
+#include <dbushelper.h>
+
 //#include "modeltest.h"
 
+//In older Qt released, qAsConst isnt available
+#include "core/qtcompat_p.h"
+
 NotificationsModel::NotificationsModel(QObject* parent)
     : QAbstractListModel(parent)
     , m_dbusInterface(nullptr)
@@ -47,7 +51,7 @@ NotificationsModel::NotificationsModel(QObject* parent)
             this, &NotificationsModel::anyDismissableChanged);
 
     QDBusServiceWatcher* watcher = new QDBusServiceWatcher(DaemonDbusInterface::activatedService(),
-                                                           QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
+                                                           DBusHelper::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
     connect(watcher, &QDBusServiceWatcher::serviceRegistered, this, &NotificationsModel::refreshNotificationList);
     connect(watcher, &QDBusServiceWatcher::serviceUnregistered, this, &NotificationsModel::clearNotifications);
 }
@@ -56,9 +60,9 @@ QHash<int, QByteArray> NotificationsModel::roleNames() const
 {
     //Role names for QML
     QHash<int, QByteArray> names = QAbstractItemModel::roleNames();
-    names.insert(DbusInterfaceRole,    "dbusInterface");
-    names.insert(AppNameModelRole,     "appName");
-    names.insert(IdModelRole,          "notificationId");
+    names.insert(DbusInterfaceRole, "dbusInterface");
+    names.insert(AppNameModelRole, "appName");
+    names.insert(IdModelRole, "notificationId");
     names.insert(DismissableModelRole, "dismissable");
     names.insert(RepliableModelRole, "repliable");
     names.insert(IconPathModelRole, "appIcon");
@@ -193,7 +197,7 @@ QVariant NotificationsModel::data(const QModelIndex& index, int role) const
         case AppNameModelRole:
             return notification->appName();
         case DbusInterfaceRole:
-            return qVariantFromValue<QObject*>(notification);
+            return QVariant::fromValue<QObject*>(notification);
         case DismissableModelRole:
             return notification->dismissable();
         case RepliableModelRole:
