@@ -15,26 +15,16 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "kcm.h"
 
-#include <QLabel>
-#include <QMenu>
-#include <QMenuBar>
-#include <QAction>
-#include <QStackedLayout>
-#include <QListView>
-#include <QDBusConnection>
-#include <QDBusInterface>
-
-#include <KServiceTypeTrader>
 #include <KPluginInfo>
 #include <KPluginMetaData>
-#include <KPluginFactory>
 #include <KAboutData>
 #include <KLocalizedString>
+#include <kcmutils_version.h>
 
 #include "ui_kcm.h"
 #include "interfaces/dbusinterfaces.h"
@@ -46,7 +36,7 @@ K_PLUGIN_FACTORY(KdeConnectKcmFactory, registerPlugin<KdeConnectKcm>();)
 
 static QString createId() { return QStringLiteral("kcm")+QString::number(QCoreApplication::applicationPid()); }
 
-KdeConnectKcm::KdeConnectKcm(QWidget* parent, const QVariantList&)
+KdeConnectKcm::KdeConnectKcm(QWidget* parent, const QVariantList& args)
     : KCModule(KAboutData::pluginData(QStringLiteral("kdeconnect-kcm")), parent)
     , kcmUi(new Ui::KdeConnectKcmUi())
     , daemon(new DaemonDbusInterface(this))
@@ -77,7 +67,7 @@ KdeConnectKcm::KdeConnectKcm(QWidget* parent, const QVariantList&)
 
     //Workaround: If we set this directly (or if we set it in the .ui file), the layout breaks
     kcmUi->noDeviceLinks->setWordWrap(false);
-    QTimer::singleShot(0, [this] { kcmUi->noDeviceLinks->setWordWrap(true); });
+    QTimer::singleShot(0, this, [this] { kcmUi->noDeviceLinks->setWordWrap(true); });
 
     setWhenAvailable(daemon->announcedName(), [this](const QString& announcedName) {
         kcmUi->rename_label->setText(announcedName);
@@ -115,6 +105,29 @@ KdeConnectKcm::KdeConnectKcm(QWidget* parent, const QVariantList&)
             this, &KdeConnectKcm::renameShow);
 
     daemon->acquireDiscoveryMode(createId());
+
+    #if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 45, 0)
+
+    if (!args.isEmpty() && args.first().type() == QVariant::String) {
+        const QString input = args.first().toString();
+        const auto colonIdx = input.indexOf(QLatin1Char(':'));
+        const QString deviceId = input.left(colonIdx);
+        const QString pluginCM = colonIdx < 0 ? QString() : input.mid(colonIdx+1);
+
+        connect(devicesModel, &DevicesModel::rowsInserted, this, [this, deviceId, pluginCM]() {
+            auto row = devicesModel->rowForDevice(deviceId);
+            if (row >= 0) {
+                const QModelIndex idx = sortProxyModel->mapFromSource(devicesModel->index(row));
+                kcmUi->deviceList->selectionModel()->setCurrentIndex(idx, QItemSelectionModel::ClearAndSelect);
+            }
+            if (!pluginCM.isEmpty()) {
+                kcmUi->pluginSelector->showConfiguration(pluginCM);
+            }
+            disconnect(devicesModel, &DevicesModel::rowsInserted, this, nullptr);
+        });
+    }
+
+    #endif
 }
 
 void KdeConnectKcm::renameShow()
