@@ -15,13 +15,13 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 
 #include "kiokdeconnect.h"
 
-#include <QtCore/QThread>
+#include <QThread>
 #include <QDBusMetaType>
 
 #include <KLocalizedString>
@@ -41,7 +41,7 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char** argv)
 {
     QCoreApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("kio_kdeconnect"));
-    
+
     if (argc != 4) {
         fprintf(stderr, "Usage: kio_kdeconnect protocol pool app\n");
         exit(-1);
@@ -55,18 +55,18 @@ extern "C" int Q_DECL_EXPORT kdemain(int argc, char** argv)
 //Some useful error mapping
 KIO::Error toKioError(const QDBusError::ErrorType type)
 {
-    switch (type) 
+    switch (type)
     {
         case QDBusError::NoError:
             return KIO::Error(KJob::NoError);
         case QDBusError::NoMemory:
             return KIO::ERR_OUT_OF_MEMORY;
-        case QDBusError::Timeout:          
+        case QDBusError::Timeout:
             return KIO::ERR_SERVER_TIMEOUT;
-        case QDBusError::TimedOut:          
+        case QDBusError::TimedOut:
             return KIO::ERR_SERVER_TIMEOUT;
         default:
-            return KIO::ERR_INTERNAL;
+            return KIO::ERR_SLAVE_DEFINED;
     };
 };
 
@@ -102,26 +102,32 @@ void KioKdeconnect::listAllDevices()
 
         if (!interface.hasPlugin(QStringLiteral("kdeconnect_sftp"))) continue;
 
-        const QString path = QStringLiteral("kdeconnect://").append(deviceId).append("/");
+        const QString path = QStringLiteral("kdeconnect://").append(deviceId).append(QStringLiteral("/"));
         const QString name = interface.name();
         const QString icon = QStringLiteral("kdeconnect");
 
         KIO::UDSEntry entry;
-        entry.insert(KIO::UDSEntry::UDS_NAME, name);
-        entry.insert(KIO::UDSEntry::UDS_ICON_NAME, icon);
-        entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-        entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String(""));
-        entry.insert(KIO::UDSEntry::UDS_URL, path);
+        entry.reserve(6);
+        entry.fastInsert(KIO::UDSEntry::UDS_NAME, name);
+        entry.fastInsert(KIO::UDSEntry::UDS_ICON_NAME, icon);
+        entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
+        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, QFileDevice::ReadOwner | QFileDevice::ExeOwner
+                                                | QFileDevice::ReadGroup | QFileDevice::ExeGroup
+                                                | QFileDevice::ReadOther | QFileDevice::ExeOther);
+        entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String(""));
+        entry.fastInsert(KIO::UDSEntry::UDS_URL, path);
         listEntry(entry);
     }
 
     // We also need a non-null and writable UDSentry for "."
     KIO::UDSEntry entry;
-    entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-    entry.insert(KIO::UDSEntry::UDS_SIZE, 0);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IXOTH);
+    entry.reserve(4);
+    entry.fastInsert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
+    entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
+    entry.fastInsert(KIO::UDSEntry::UDS_SIZE, 0);
+    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, QFileDevice::ReadOwner | QFileDevice::WriteOwner
+                    | QFileDevice::ExeOwner | QFileDevice::ReadGroup | QFileDevice::WriteGroup
+                    | QFileDevice::ExeGroup | QFileDevice::ReadOther | QFileDevice::ExeOther);
     listEntry(entry);
 
     infoMessage(QLatin1String(""));
@@ -173,7 +179,7 @@ void KioKdeconnect::listDevice(const QString& device)
     }
 
     if (!mountreply.value()) {
-        error(KIO::ERR_COULD_NOT_MOUNT, i18n("Could not mount device filesystem"));
+        error(KIO::ERR_SLAVE_DEFINED, interface.getMountError());
         return;
     }
 
@@ -192,22 +198,28 @@ void KioKdeconnect::listDevice(const QString& device)
         const QString icon = QStringLiteral("folder");
 
         KIO::UDSEntry entry;
-        entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("files"));
-        entry.insert(KIO::UDSEntry::UDS_DISPLAY_NAME, name);
-        entry.insert(KIO::UDSEntry::UDS_ICON_NAME, icon);
-        entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-        entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IXUSR | S_IRGRP | S_IXGRP | S_IROTH | S_IXOTH);
-        entry.insert(KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String(""));
-        entry.insert(KIO::UDSEntry::UDS_URL, QUrl::fromLocalFile(path).toString());
+        entry.reserve(6);
+        entry.fastInsert(KIO::UDSEntry::UDS_NAME, name);
+        entry.fastInsert(KIO::UDSEntry::UDS_ICON_NAME, icon);
+        entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
+        entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, QFileDevice::ReadOwner | QFileDevice::ExeOwner
+                                                | QFileDevice::ReadGroup | QFileDevice::ExeGroup
+                                                | QFileDevice::ReadOther | QFileDevice::ExeOther);
+        entry.fastInsert(KIO::UDSEntry::UDS_MIME_TYPE, QLatin1String(""));
+        entry.fastInsert(KIO::UDSEntry::UDS_URL, QUrl::fromLocalFile(path).toString());
         listEntry(entry);
     }
 
     // We also need a non-null and writable UDSentry for "."
     KIO::UDSEntry entry;
-    entry.insert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
-    entry.insert(KIO::UDSEntry::UDS_SIZE, 0);
-    entry.insert(KIO::UDSEntry::UDS_ACCESS, S_IRUSR | S_IWUSR | S_IXUSR | S_IRGRP | S_IWGRP | S_IXGRP | S_IROTH | S_IXOTH);
+    entry.reserve(4);
+    entry.fastInsert(KIO::UDSEntry::UDS_NAME, QStringLiteral("."));
+    entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
+    entry.fastInsert(KIO::UDSEntry::UDS_SIZE, 0);
+    entry.fastInsert(KIO::UDSEntry::UDS_ACCESS, QFileDevice::ReadOwner | QFileDevice::WriteOwner
+                    | QFileDevice::ExeOwner | QFileDevice::ReadGroup | QFileDevice::WriteGroup
+                    | QFileDevice::ExeGroup | QFileDevice::ReadOther | QFileDevice::ExeOther);
+
     listEntry(entry);
 
     infoMessage(QLatin1String(""));
@@ -241,14 +253,14 @@ void KioKdeconnect::stat(const QUrl& url)
     qCDebug(KDECONNECT_KIO) << "Stat: " << url;
 
     KIO::UDSEntry entry;
-    entry.insert(KIO::UDSEntry::UDS_FILE_TYPE, S_IFDIR);
+    entry.fastInsert(KIO::UDSEntry::UDS_FILE_TYPE, QT_STAT_DIR);
 
     QString currentDevice = url.host();
     if (!currentDevice.isEmpty()) {
         SftpDbusInterface interface(currentDevice);
 
         if (interface.isValid()) {
-            entry.insert(KIO::UDSEntry::UDS_LOCAL_PATH, interface.mountPoint());
+            entry.fastInsert(KIO::UDSEntry::UDS_LOCAL_PATH, interface.mountPoint());
 
             if (!interface.isMounted()) {
                 interface.mount();
