@@ -15,12 +15,11 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "batteryplugin.h"
 
-#include <QIcon>
 #include <KLocalizedString>
 #include <KPluginFactory>
 
@@ -28,7 +27,7 @@
 
 #include "batterydbusinterface.h"
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_battery.json", registerPlugin< BatteryPlugin >(); )
+K_PLUGIN_CLASS_WITH_JSON(BatteryPlugin, "kdeconnect_battery.json")
 
 Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_BATTERY, "kdeconnect.plugin.battery")
 
@@ -38,13 +37,13 @@ BatteryPlugin::BatteryPlugin(QObject* parent, const QVariantList& args)
 {
 
     //TODO: Add battery reporting, could be based on:
-    // http://kde-apps.org/content/show.php/battery+plasmoid+with+remaining+time?content=120309
+    // https://www.linux-apps.com/content/show.php/battery+plasmoid+with+remaining+time?content=120309
 
 }
 
 void BatteryPlugin::connected()
 {
-    NetworkPacket np(PACKET_TYPE_BATTERY_REQUEST, {{"request",true}});
+    NetworkPacket np(PACKET_TYPE_BATTERY_REQUEST, {{QStringLiteral("request"),true}});
     sendPacket(np);
 }
 
@@ -73,7 +72,6 @@ bool BatteryPlugin::receivePacket(const NetworkPacket& np)
 
     if ( thresholdEvent == ThresholdBatteryLow && !isCharging ) {
         Daemon::instance()->sendSimpleNotification(QStringLiteral("batteryLow"), i18nc("device name: low battery", "%1: Low Battery", device()->name()), i18n("Battery at %1%", currentCharge), QStringLiteral("battery-040"));
-
     }
 
     return true;
