@@ -15,13 +15,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "mpriscontrolplugin.h"
 
 #include <QDBusArgument>
-#include <QDBusConnection>
 #include <QDBusInterface>
 #include <qdbusconnectioninterface.h>
 #include <QDBusReply>
@@ -31,10 +30,11 @@
 #include <KPluginFactory>
 
 #include <core/device.h>
+#include <dbushelper.h>
 #include "mprisdbusinterface.h"
 #include "propertiesdbusinterface.h"
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_mpriscontrol.json", registerPlugin< MprisControlPlugin >(); )
+K_PLUGIN_CLASS_WITH_JSON(MprisControlPlugin, "kdeconnect_mpriscontrol.json")
 
 Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_MPRIS, "kdeconnect.plugin.mpris")
 
@@ -52,13 +52,13 @@ MprisControlPlugin::MprisControlPlugin(QObject* parent, const QVariantList& args
     : KdeConnectPlugin(parent, args)
     , prevVolume(-1)
 {
-    m_watcher = new QDBusServiceWatcher(QString(), QDBusConnection::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
+    m_watcher = new QDBusServiceWatcher(QString(), DBusHelper::sessionBus(), QDBusServiceWatcher::WatchForOwnerChange, this);
 
     // TODO: QDBusConnectionInterface::serviceOwnerChanged is deprecated, maybe query org.freedesktop.DBus directly?
-    connect(QDBusConnection::sessionBus().interface(), &QDBusConnectionInterface::serviceOwnerChanged, this, &MprisControlPlugin::serviceOwnerChanged);
+    connect(DBusHelper::sessionBus().interface(), &QDBusConnectionInterface::serviceOwnerChanged, this, &MprisControlPlugin::serviceOwnerChanged);
 
     //Add existing interfaces
-    const QStringList services = QDBusConnection::sessionBus().interface()->registeredServiceNames().value();
+    const QStringList services = DBusHelper::sessionBus().interface()->registeredServiceNames().value();
     for (const QString& service : services) {
         // The string doesn't matter, it just needs to be empty/non-empty
         serviceOwnerChanged(service, QLatin1String(""), QStringLiteral("1"));
@@ -100,7 +100,7 @@ void MprisControlPlugin::addPlayer(const QString& service)
         uniqueName = identity + QLatin1String(" [") + QString::number(i) + QLatin1Char(']');
     }
 
-    MprisPlayer player(service, mediaPlayerObjectPath, QDBusConnection::sessionBus());
+    MprisPlayer player(service, mediaPlayerObjectPath, DBusHelper::sessionBus());
 
     playerList.insert(uniqueName, player);
 
@@ -128,8 +128,8 @@ void MprisControlPlugin::seeked(qlonglong position){
     const QString& playerName = it.key();
 
     NetworkPacket np(PACKET_TYPE_MPRIS, {
-        {"pos", position/1000}, //Send milis instead of nanos
-        {"player", playerName}
+        {QStringLiteral("pos"), position/1000}, //Send milis instead of nanos
+        {QStringLiteral("player"), playerName}
     });
     sendPacket(np);
 }
@@ -246,7 +246,7 @@ bool MprisControlPlugin::sendAlbumArt(const NetworkPacket& np)
     }
 
     //Only support sending local files
-    if (playerAlbumArtUrl.scheme() != "file") {
+    if (playerAlbumArtUrl.scheme() != QStringLiteral("file")) {
         return false;
     }
 
@@ -363,7 +363,7 @@ void MprisControlPlugin::mprisPlayerMetadataToNetworkPacket(NetworkPacket& np, c
     QString albumArtUrl = nowPlayingMap[QStringLiteral("mpris:artUrl")].toString();
     QString nowPlaying = title;
     if (!artist.isEmpty()) {
-        nowPlaying = artist + " - " + title;
+        nowPlaying = artist + QStringLiteral(" - ") + title;
     }
     np.set(QStringLiteral("title"), title);
     np.set(QStringLiteral("artist"), artist);
