@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef NOTIFICATION_H
@@ -28,25 +28,26 @@
 #include <QPointer>
 
 #include <core/networkpacket.h>
+#include <core/device.h>
 
 class Notification
     : public QObject
 {
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.notifications.notification")
-    Q_PROPERTY(QString internalId READ internalId)
-    Q_PROPERTY(QString appName READ appName)
-    Q_PROPERTY(QString ticker READ ticker)
-    Q_PROPERTY(QString title READ title)
-    Q_PROPERTY(QString text READ text)
-    Q_PROPERTY(QString iconPath READ iconPath)
-    Q_PROPERTY(bool dismissable READ dismissable)
-    Q_PROPERTY(bool hasIcon READ hasIcon)
-    Q_PROPERTY(bool silent READ silent)
-    Q_PROPERTY(QString replyId READ replyId)
+    Q_PROPERTY(QString internalId READ internalId CONSTANT)
+    Q_PROPERTY(QString appName READ appName NOTIFY ready)
+    Q_PROPERTY(QString ticker READ ticker NOTIFY ready)
+    Q_PROPERTY(QString title READ title NOTIFY ready)
+    Q_PROPERTY(QString text READ text NOTIFY ready)
+    Q_PROPERTY(QString iconPath READ iconPath NOTIFY ready)
+    Q_PROPERTY(bool dismissable READ dismissable NOTIFY ready)
+    Q_PROPERTY(bool hasIcon READ hasIcon NOTIFY ready)
+    Q_PROPERTY(bool silent READ silent NOTIFY ready)
+    Q_PROPERTY(QString replyId READ replyId NOTIFY ready)
 
 public:
-    Notification(const NetworkPacket& np, QObject* parent);
+    Notification(const NetworkPacket& np, const Device* device, QObject* parent);
     ~Notification() override;
 
     QString internalId() const { return m_internalId; }
@@ -62,17 +63,17 @@ public:
     bool silent() const { return m_silent; }
     void update(const NetworkPacket& np);
     bool isReady() const { return m_ready; }
-    KNotification* createKNotification(bool update, const NetworkPacket& np);
+    void createKNotification(const NetworkPacket& np);
 
 public Q_SLOTS:
     Q_SCRIPTABLE void dismiss();
     Q_SCRIPTABLE void reply();
-    void closed();
 
-    Q_SIGNALS:
+Q_SIGNALS:
     void dismissRequested(const QString& m_internalId);
     void replyRequested();
-    void ready();
+    Q_SCRIPTABLE void ready();
+    void actionTriggered(const QString& key, const QString& action);
 
 private:
     QString m_internalId;
@@ -84,12 +85,13 @@ private:
     QString m_requestReplyId;
     bool m_dismissable;
     bool m_hasIcon;
-    KNotification* m_notification;
+    QPointer<KNotification> m_notification;
     QDir m_imagesDir;
     bool m_silent;
-    bool m_closed;
     QString m_payloadHash;
     bool m_ready;
+    QStringList m_actions;
+    const Device* m_device;
 
     void parseNetworkPacket(const NetworkPacket& np);
     void loadIcon(const NetworkPacket& np);
