@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "pingplugin.h"
@@ -30,7 +30,7 @@
 #include <core/device.h>
 #include <core/daemon.h>
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_ping.json", registerPlugin< PingPlugin >(); )
+K_PLUGIN_CLASS_WITH_JSON(PingPlugin, "kdeconnect_ping.json")
 
 Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_PING, "kdeconnect.plugin.ping")
 
@@ -71,7 +71,7 @@ void PingPlugin::sendPing(const QString& customMessage)
 
 QString PingPlugin::dbusPath() const
 {
-    return "/modules/kdeconnect/devices/" + device()->id() + "/ping";
+    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/ping");
 }
 
 #include "pingplugin.moc"
