@@ -15,19 +15,15 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef REMOTECOMMANDSPLUGIN_H
 #define REMOTECOMMANDSPLUGIN_H
 
-#include <QObject>
+class QObject;
 
 #include <core/kdeconnectplugin.h>
-#include <QFile>
-#include <QFileSystemWatcher>
-#include <QMap>
-#include <QPair>
 #include <QString>
 
 class Q_DECL_EXPORT RemoteCommandsPlugin
@@ -36,13 +32,19 @@ class Q_DECL_EXPORT RemoteCommandsPlugin
     Q_OBJECT
     Q_CLASSINFO("D-Bus Interface", "org.kde.kdeconnect.device.remotecommands")
     Q_PROPERTY(QByteArray commands READ commands NOTIFY commandsChanged)
+    Q_PROPERTY(QString deviceId READ deviceId CONSTANT)
+    Q_PROPERTY(bool canAddCommand READ canAddCommand CONSTANT)
 
 public:
     explicit RemoteCommandsPlugin(QObject* parent, const QVariantList& args);
     ~RemoteCommandsPlugin() override;
 
     Q_SCRIPTABLE void triggerCommand(const QString& key);
+    Q_SCRIPTABLE void editCommands();
+
     QByteArray commands() const { return m_commands; }
+    QString deviceId() const { return device()->id(); }
+    bool canAddCommand() const { return m_canAddCommand; }
 
     bool receivePacket(const NetworkPacket& np) override;
     void connected() override;
@@ -55,6 +57,7 @@ private:
     void setCommands(const QByteArray& commands);
 
     QByteArray m_commands;
+    bool m_canAddCommand;
 };
 
 #endif
