@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "runcommandplugin.h"
@@ -29,13 +29,24 @@
 #include <QSettings>
 #include <QJsonDocument>
 #include <KShell>
+#include <kcmutils_version.h>
 
 #include <core/networkpacket.h>
 #include <core/device.h>
 
 #define PACKET_TYPE_RUNCOMMAND QStringLiteral("kdeconnect.runcommand")
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_runcommand.json", registerPlugin< RunCommandPlugin >(); )
+#ifdef Q_OS_WIN
+#define COMMAND "cmd"
+#define ARGS "/c"
+
+#else
+#define COMMAND "/bin/sh"
+#define ARGS "-c"
+
+#endif
+
+K_PLUGIN_CLASS_WITH_JSON(RunCommandPlugin, "kdeconnect_runcommand.json")
 
 Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_RUNCOMMAND, "kdeconnect.plugin.runcommand")
 
@@ -65,9 +76,11 @@ bool RunCommandPlugin::receivePacket(const NetworkPacket& np)
             qCWarning(KDECONNECT_PLUGIN_RUNCOMMAND) << key << "is not a configured command";
         }
         const QJsonObject commandJson = value.toObject();
-        qCInfo(KDECONNECT_PLUGIN_RUNCOMMAND) << "Running:" << "/bin/sh" << "-c" << commandJson[QStringLiteral("command")].toString();
-        QProcess::startDetached(QStringLiteral("/bin/sh"), QStringList()<< QStringLiteral("-c") << commandJson[QStringLiteral("command")].toString());
+        qCInfo(KDECONNECT_PLUGIN_RUNCOMMAND) << "Running:" << COMMAND << ARGS << commandJson[QStringLiteral("command")].toString();
+        QProcess::startDetached(QStringLiteral(COMMAND), QStringList()<< QStringLiteral(ARGS) << commandJson[QStringLiteral("command")].toString());
         return true;
+    } else if (np.has(QStringLiteral("setup"))) {
+        QProcess::startDetached(QStringLiteral("kcmshell5"), {QStringLiteral("kdeconnect"), QStringLiteral("--args"), QString(device()->id() + QStringLiteral(":kdeconnect_runcommand")) });
     }
 
     return false;
@@ -82,7 +95,12 @@ void RunCommandPlugin::connected()
 void RunCommandPlugin::sendConfig()
 {
     QString commands = config()->get<QString>(QStringLiteral("commands"),QStringLiteral("{}"));
-    NetworkPacket np(PACKET_TYPE_RUNCOMMAND, {{"commandList", commands}});
+    NetworkPacket np(PACKET_TYPE_RUNCOMMAND, {{QStringLiteral("commandList"), commands}});
+
+    #if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 45, 0)
+        np.set<bool>(QStringLiteral("canAddCommand"), true);
+    #endif
+
     sendPacket(np);
 }
 
