@@ -15,38 +15,36 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "screensaverinhibitplugin.h"
 
-#include <QDebug>
 #include <KLocalizedString>
 #include <KPluginFactory>
 #include <QLoggingCategory>
-#include <core/device.h>
 #include <QDBusConnection>
 #include <QDBusInterface>
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_screensaver_inhibit.json", registerPlugin< ScreensaverInhibitPlugin >(); )
+K_PLUGIN_CLASS_WITH_JSON(ScreensaverInhibitPlugin, "kdeconnect_screensaver_inhibit.json")
 
 Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_SCREENSAVERINHIBIT, "kdeconnect.plugin.screensaverinhibit")
 
-const QString INHIBIT_SERVICE = QStringLiteral("org.freedesktop.ScreenSaver");
-const QString INHIBIT_INTERFACE = INHIBIT_SERVICE;
-const QString INHIBIT_PATH = QStringLiteral("/ScreenSaver");
-const QString INHIBIT_METHOD = QStringLiteral("Inhibit");
-const QString UNINHIBIT_METHOD = QStringLiteral("UnInhibit");
-const QString SIMULATE_ACTIVITY_METHOD = QStringLiteral("SimulateUserActivity");
+#define INHIBIT_SERVICE QStringLiteral("org.freedesktop.ScreenSaver")
+#define INHIBIT_INTERFACE INHIBIT_SERVICE
+#define INHIBIT_PATH QStringLiteral("/ScreenSaver")
+#define INHIBIT_METHOD QStringLiteral("Inhibit")
+#define UNINHIBIT_METHOD QStringLiteral("UnInhibit")
+#define SIMULATE_ACTIVITY_METHOD QStringLiteral("SimulateUserActivity")
 
 ScreensaverInhibitPlugin::ScreensaverInhibitPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
 {
     QDBusInterface inhibitInterface(INHIBIT_SERVICE, INHIBIT_PATH, INHIBIT_INTERFACE);
 
-    QDBusMessage reply = inhibitInterface.call(INHIBIT_METHOD, "kdeconnect", "Phone is connected");
+    QDBusMessage reply = inhibitInterface.call(INHIBIT_METHOD, QStringLiteral("org.kde.kdeconnect.daemon"), i18n("Phone is connected"));
 
-    if (reply.errorMessage() != nullptr) {
+    if (!reply.errorMessage().isEmpty()) {
         qCDebug(KDECONNECT_PLUGIN_SCREENSAVERINHIBIT) << "Unable to inhibit the screensaver: " << reply.errorMessage();
         inhibitCookie = 0;
     } else {
@@ -73,7 +71,6 @@ ScreensaverInhibitPlugin::~ScreensaverInhibitPlugin()
 
 void ScreensaverInhibitPlugin::connected()
 {
-
 }
 
 bool ScreensaverInhibitPlugin::receivePacket(const NetworkPacket& np)
@@ -82,5 +79,4 @@ bool ScreensaverInhibitPlugin::receivePacket(const NetworkPacket& np)
     return false;
 }
 
-
 #include "screensaverinhibitplugin.moc"
