@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "mounter.h"
@@ -83,6 +83,11 @@ void Mounter::onPackageReceived(const NetworkPacket& np)
         return;
     }
 
+    if (np.has(QStringLiteral("errorMessage"))) {
+        Q_EMIT failed(np.get<QString>(QStringLiteral("errorMessage")));
+        return;
+    }
+
     //This is the previous code, to access sftp server using KIO. Now we are
     //using the external binary sshfs, and accessing it as a local filesystem.
   /*
@@ -103,15 +108,15 @@ void Mounter::onPackageReceived(const NetworkPacket& np)
     m_proc->setOutputChannelMode(KProcess::MergedChannels);
 
     connect(m_proc, &QProcess::started, this, &Mounter::onStarted);
-    connect(m_proc, SIGNAL(error(QProcess::ProcessError)), SLOT(onError(QProcess::ProcessError)));
-    connect(m_proc, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(onFinished(int,QProcess::ExitStatus)));
+    connect(m_proc, &QProcess::errorOccurred, this, &Mounter::onError);
+    connect(m_proc, QOverload<int, QProcess::ExitStatus>::of(&QProcess::finished), this, &Mounter::onFinished);
 
     QDir().mkpath(m_mountPoint);
 
     const QString program = QStringLiteral("sshfs");
 
     QString path;
-    if (np.has(QStringLiteral("multiPaths"))) path = '/';
+    if (np.has(QStringLiteral("multiPaths"))) path = QStringLiteral("/");
     else path = np.get<QString>(QStringLiteral("path"));
 
     QHostAddress addr = m_sftp->device()->getLocalIpAddress();
@@ -131,7 +136,7 @@ void Mounter::onPackageReceived(const NetworkPacket& np)
         << QStringLiteral("-s") // This fixes a bug where file chunks are sent out of order and get corrupted on reception
         << QStringLiteral("-f")
         << QStringLiteral("-F") << QStringLiteral("/dev/null") //Do not use ~/.ssh/config
-        << QStringLiteral("-o") << "IdentityFile=" + KdeConnectConfig::instance()->privateKeyPath()
+        << QStringLiteral("-o") << QStringLiteral("IdentityFile=") + KdeConnectConfig::instance().privateKeyPath()
         << QStringLiteral("-o") << QStringLiteral("StrictHostKeyChecking=no") //Do not ask for confirmation because it is not a known host
         << QStringLiteral("-o") << QStringLiteral("UserKnownHostsFile=/dev/null") //Prevent storing as a known host
         << QStringLiteral("-o") << QStringLiteral("HostKeyAlgorithms=+ssh-dss") //https://bugs.kde.org/show_bug.cgi?id=351725
@@ -163,10 +168,10 @@ void Mounter::onStarted()
     //m_proc->setStandardErrorFile("/tmp/kdeconnect-sftp.err");
 
     auto proc = m_proc;
-    connect(m_proc, &KProcess::readyReadStandardError, [proc]() {
+    connect(m_proc, &KProcess::readyReadStandardError, this, [proc]() {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "stderr: " << proc->readAll();
     });
-    connect(m_proc, &KProcess::readyReadStandardOutput, [proc]() {
+    connect(m_proc, &KProcess::readyReadStandardOutput, this, [proc]() {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "stdout:" << proc->readAll();
     });
 }
@@ -175,15 +180,23 @@ void Mounter::onError(QProcess::ProcessError error)
 {
     if (error == QProcess::FailedToStart)
     {
-        qCDebug(KDECONNECT_PLUGIN_SFTP) << "Process failed to start";
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "sshfs process failed to start";
         m_started = false;
         Q_EMIT failed(i18n("Failed to start sshfs"));
+    } else if(error == QProcess::ProcessError::Crashed) {
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "sshfs process crashed";
+        m_started = false;
+        Q_EMIT failed(i18n("sshfs process crashed"));
+    } else {
+        qCDebug(KDECONNECT_PLUGIN_SFTP) << "sshfs process error" << error;
+        m_started = false;
+        Q_EMIT failed(i18n("Unknown error in sshfs"));
     }
 }
 
 void Mounter::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    if (exitStatus == QProcess::NormalExit)
+    if (exitStatus == QProcess::NormalExit && exitCode == 0)
     {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "Process finished (exit code: " << exitCode << ")";
         Q_EMIT unmounted();
@@ -191,7 +204,7 @@ void Mounter::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
     else
     {
         qCDebug(KDECONNECT_PLUGIN_SFTP) << "Process failed (exit code:" << exitCode << ")";
-        Q_EMIT failed(i18n("Error when accessing to filesystem"));
+        Q_EMIT failed(i18n("Error when accessing filesystem. sshfs finished with exit code %0").arg(exitCode));
     }
 
     unmount(true);
@@ -205,7 +218,7 @@ void Mounter::onMountTimeout()
 
 void Mounter::start()
 {
-    NetworkPacket np(PACKET_TYPE_SFTP_REQUEST, {{"startBrowsing", true}});
+    NetworkPacket np(PACKET_TYPE_SFTP_REQUEST, {{QStringLiteral("startBrowsing"), true}});
     m_sftp->sendPacket(np);
 
     m_connectTimer.start();
