@@ -1,5 +1,6 @@
 /**
  * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * Copyright 2018 Simon Redman <simon@ergotech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -15,27 +16,24 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "telephonyplugin.h"
 
-#include "sendreplydialog.h"
-
 #include <KLocalizedString>
-#include <QIcon>
 #include <QDebug>
 #include <QDBusReply>
 
 #include <KPluginFactory>
+#include <KNotification>
 
-K_PLUGIN_FACTORY_WITH_JSON( KdeConnectPluginFactory, "kdeconnect_telephony.json", registerPlugin< TelephonyPlugin >(); )
+K_PLUGIN_CLASS_WITH_JSON(TelephonyPlugin, "kdeconnect_telephony.json")
 
 Q_LOGGING_CATEGORY(KDECONNECT_PLUGIN_TELEPHONY, "kdeconnect.plugin.telephony")
 
 TelephonyPlugin::TelephonyPlugin(QObject* parent, const QVariantList& args)
     : KdeConnectPlugin(parent, args)
-    , m_telepathyInterface(QStringLiteral("org.freedesktop.Telepathy.ConnectionManager.kdeconnect"), QStringLiteral("/kdeconnect"))
 {
 }
 
@@ -46,19 +44,6 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPacket& np)
     const QString contactName = np.get<QString>(QStringLiteral("contactName"), phoneNumber);
     const QByteArray phoneThumbnail = QByteArray::fromBase64(np.get<QByteArray>(QStringLiteral("phoneThumbnail"), ""));
 
-    // In case telepathy can handle the message, don't do anything else
-    if (event == QLatin1String("sms") && m_telepathyInterface.isValid()) {
-        qCDebug(KDECONNECT_PLUGIN_TELEPHONY) << "Passing a text message to the telepathy interface";
-        connect(&m_telepathyInterface, SIGNAL(messageReceived(QString,QString)), SLOT(sendSms(QString,QString)), Qt::UniqueConnection);
-        const QString messageBody = np.get<QString>(QStringLiteral("messageBody"),QLatin1String(""));
-        QDBusReply<bool> reply = m_telepathyInterface.call(QStringLiteral("sendMessage"), phoneNumber, contactName, messageBody);
-        if (reply) {
-            return nullptr;
-        } else {
-            qCDebug(KDECONNECT_PLUGIN_TELEPHONY) << "Telepathy failed, falling back to the default handling";
-        }
-    }
-
     QString content, type, icon;
     KNotification::NotificationFlags flags = KNotification::CloseOnTimeout;
 
@@ -73,12 +58,6 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPacket& np)
         icon = QStringLiteral("call-start");
         content = i18n("Missed call from %1", contactName);
         flags |= KNotification::Persistent; //Note that in Unity this generates a message box!
-    } else if (event == QLatin1String("sms")) {
-        type = QStringLiteral("smsReceived");
-        icon = QStringLiteral("mail-receive");
-        QString messageBody = np.get<QString>(QStringLiteral("messageBody"), QLatin1String(""));
-        content = i18n("SMS from %1<br>%2", contactName, messageBody);
-        flags |= KNotification::Persistent; //Note that in Unity this generates a message box!
     } else if (event == QLatin1String("talking")) {
         return nullptr;
     } else {
@@ -91,6 +70,8 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPacket& np)
 #endif
     }
 
+    Q_EMIT callReceived(type, phoneNumber, contactName);
+
     qCDebug(KDECONNECT_PLUGIN_TELEPHONY) << "Creating notification with type:" << type;
 
     KNotification* notification = new KNotification(type, flags, this);
@@ -108,17 +89,8 @@ KNotification* TelephonyPlugin::createNotification(const NetworkPacket& np)
     if (event == QLatin1String("ringing")) {
         notification->setActions( QStringList(i18n("Mute Call")) );
         connect(notification, &KNotification::action1Activated, this, &TelephonyPlugin::sendMutePacket);
-    } else if (event == QLatin1String("sms")) {
-        const QString messageBody = np.get<QString>(QStringLiteral("messageBody"),QLatin1String(""));
-        notification->setActions( QStringList(i18n("Reply")) );
-        notification->setProperty("phoneNumber", phoneNumber);
-        notification->setProperty("contactName", contactName);
-        notification->setProperty("originalMessage", messageBody);
-        connect(notification, &KNotification::action1Activated, this, &TelephonyPlugin::showSendSmsDialog);
     }
-
     return notification;
-
 }
 
 bool TelephonyPlugin::receivePacket(const NetworkPacket& np)
@@ -129,42 +101,30 @@ bool TelephonyPlugin::receivePacket(const NetworkPacket& np)
         return true;
     }
 
-    KNotification* n = createNotification(np);
-    if (n != nullptr) n->sendEvent();
+    const QString& event = np.get<QString>(QStringLiteral("event"), QStringLiteral("unknown"));
+
+    // Handle old-style packets
+    if (np.type() == PACKET_TYPE_TELEPHONY) {
+        if (event == QLatin1String("sms")) {
+            return false;
+        }
+        KNotification* n = createNotification(np);
+        if (n != nullptr) n->sendEvent();
+        return true;
+    }
 
     return true;
 }
 
 void TelephonyPlugin::sendMutePacket()
 {
-    NetworkPacket packet(PACKET_TYPE_TELEPHONY_REQUEST, {{"action", "mute"}});
+    NetworkPacket packet(PACKET_TYPE_TELEPHONY_REQUEST_MUTE, {{QStringLiteral("action"), QStringLiteral("mute")}});
     sendPacket(packet);
 }
 
-void TelephonyPlugin::sendSms(const QString& phoneNumber, const QString& messageBody)
-{
-    NetworkPacket np(PACKET_TYPE_SMS_REQUEST, {
-        {"sendSms", true},
-        {"phoneNumber", phoneNumber},
-        {"messageBody", messageBody}
-    });
-    sendPacket(np);
-}
-
-void TelephonyPlugin::showSendSmsDialog()
-{
-    QString phoneNumber = sender()->property("phoneNumber").toString();
-    QString contactName = sender()->property("contactName").toString();
-    QString originalMessage = sender()->property("originalMessage").toString();
-    SendReplyDialog* dialog = new SendReplyDialog(originalMessage, phoneNumber, contactName);
-    connect(dialog, &SendReplyDialog::sendReply, this, &TelephonyPlugin::sendSms);
-    dialog->show();
-    dialog->raise();
-}
-
 QString TelephonyPlugin::dbusPath() const
 {
-    return "/modules/kdeconnect/devices/" + device()->id() + "/telephony";
+    return QStringLiteral("/modules/kdeconnect/devices/") + device()->id() + QStringLiteral("/telephony");
 }
 
 #include "telephonyplugin.moc"
