@@ -1,5 +1,6 @@
 /**
  * Copyright 2013 Albert Vaca <albertvaka@gmail.com>
+ * Copyright 2018 Simon Redman <simon@ergotech.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -15,7 +16,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef TELEPHONYPLUGIN_H
@@ -28,8 +29,21 @@
 
 #include <core/kdeconnectplugin.h>
 
-#define PACKET_TYPE_TELEPHONY_REQUEST QStringLiteral("kdeconnect.telephony.request")
-#define PACKET_TYPE_SMS_REQUEST QStringLiteral("kdeconnect.sms.request")
+/**
+ * Packet used for simple telephony events
+ *
+ * It contains the key "event" which maps to a string indicating the type of event:
+ *  - "ringing" - A phone call is incoming
+ *  - "missedCall" - An incoming call was not answered
+ *
+ * Historically, "sms" was a valid event, but support for that has been dropped in favour
+ * of the SMS plugin's more expressive interfaces
+ *
+ * Depending on the event, other fields may be defined
+ */
+#define PACKET_TYPE_TELEPHONY QStringLiteral("kdeconnect.telephony")
+
+#define PACKET_TYPE_TELEPHONY_REQUEST_MUTE QStringLiteral("kdeconnect.telephony.request_mute")
 
 Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_PLUGIN_TELEPHONY)
 
@@ -41,22 +55,26 @@ class TelephonyPlugin
 
 public:
     explicit TelephonyPlugin(QObject* parent, const QVariantList& args);
+    ~TelephonyPlugin() = default;
 
     bool receivePacket(const NetworkPacket& np) override;
     void connected() override {}
     QString dbusPath() const override;
 
-public Q_SLOTS:
-    Q_SCRIPTABLE void sendSms(const QString& phoneNumber, const QString& messageBody);
+public:
+Q_SIGNALS:
+    Q_SCRIPTABLE void callReceived(const QString& event, const QString& number, const QString contactName);
 
 private Q_SLOTS:
     void sendMutePacket();
-    void showSendSmsDialog();
 
 private:
+    /**
+     * Create a notification for:
+     *  - Incoming call (with the option to mute the ringing)
+     *  - Missed call
+     */
     KNotification* createNotification(const NetworkPacket& np);
-
-    QDBusInterface m_telepathyInterface;
 };
 
 #endif
