@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "../core/device.h"
@@ -58,9 +58,8 @@ void DeviceTest::initTestCase()
 
 void DeviceTest::testPairedDevice()
 {
-    KdeConnectConfig* kcc = KdeConnectConfig::instance();
-    kcc->addTrustedDevice(deviceId, deviceName, deviceType);
-    kcc->setDeviceProperty(deviceId, QStringLiteral("certificate"), QString::fromLatin1(kcc->certificate().toPem())); // Using same certificate from kcc, instead of generating one
+    KdeConnectConfig::instance().addTrustedDevice(deviceId, deviceName, deviceType);
+    KdeConnectConfig::instance().setDeviceProperty(deviceId, QStringLiteral("certificate"), QString::fromLatin1(KdeConnectConfig::instance().certificate().toPem())); // Using same certificate from kcc, instead of generating one
 
     Device device(this, deviceId);
 
@@ -94,6 +93,8 @@ void DeviceTest::testPairedDevice()
 
 void DeviceTest::testUnpairedDevice()
 {
+    KdeConnectConfig::instance().removeTrustedDevice(deviceId);
+
     LanLinkProvider linkProvider;
     QSslSocket socket;
     LanDeviceLink* link = new LanDeviceLink(deviceId, &linkProvider, &socket, LanDeviceLink::Locally);
