@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 
@@ -32,28 +32,19 @@ class KdeConnectConfigTest : public QObject
 Q_OBJECT
 
 private Q_SLOTS:
-    void initTestCase();
     void addTrustedDevice();
 /*
     void remoteCertificateTest();
 */
     void removeTrustedDevice();
-
-private:
-    KdeConnectConfig* kcc;
 };
 
-void KdeConnectConfigTest::initTestCase()
-{
-    kcc = KdeConnectConfig::instance();
-}
-
 void KdeConnectConfigTest::addTrustedDevice()
 {
-    kcc->addTrustedDevice(QStringLiteral("testdevice"), QStringLiteral("Test Device"), QStringLiteral("phone"));
-    KdeConnectConfig::DeviceInfo devInfo = kcc->getTrustedDevice(QStringLiteral("testdevice"));
-    QCOMPARE(devInfo.deviceName, QString("Test Device"));
-    QCOMPARE(devInfo.deviceType, QString("phone"));
+    KdeConnectConfig::instance().addTrustedDevice(QStringLiteral("testdevice"), QStringLiteral("Test Device"), QStringLiteral("phone"));
+    KdeConnectConfig::DeviceInfo devInfo = KdeConnectConfig::instance().getTrustedDevice(QStringLiteral("testdevice"));
+    QCOMPARE(devInfo.deviceName, QStringLiteral("Test Device"));
+    QCOMPARE(devInfo.deviceType, QStringLiteral("phone"));
 }
 
 /*
@@ -83,10 +74,10 @@ void KdeConnectConfigTest::remoteCertificateTest()
 
 void KdeConnectConfigTest::removeTrustedDevice()
 {
-    kcc->removeTrustedDevice(QStringLiteral("testdevice"));
-    KdeConnectConfig::DeviceInfo devInfo = kcc->getTrustedDevice(QStringLiteral("testdevice"));
-    QCOMPARE(devInfo.deviceName, QString("unnamed"));
-    QCOMPARE(devInfo.deviceType, QString("unknown"));
+    KdeConnectConfig::instance().removeTrustedDevice(QStringLiteral("testdevice"));
+    KdeConnectConfig::DeviceInfo devInfo = KdeConnectConfig::instance().getTrustedDevice(QStringLiteral("testdevice"));
+    QCOMPARE(devInfo.deviceName, QStringLiteral("unnamed"));
+    QCOMPARE(devInfo.deviceType, QStringLiteral("unknown"));
 }
 
 QTEST_GUILESS_MAIN(KdeConnectConfigTest)
