@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <QSocketNotifier>
@@ -46,6 +46,10 @@ class PluginLoadTest : public QObject
 
     private Q_SLOTS:
         void testPlugins() {
+            if (!(m_daemon->getLinkProviders().size() > 0)) {
+                QFAIL("No links available, but loopback should have been provided by the test");
+            }
+
             Device* d = nullptr;
             m_daemon->acquireDiscoveryMode(QStringLiteral("plugintest"));
             const QList<Device*> devicesList = m_daemon->devicesList();
@@ -57,6 +61,9 @@ class PluginLoadTest : public QObject
                     break;
                 }
             }
+            if (d == nullptr) {
+                QFAIL("Unable to determine device");
+            }
             m_daemon->releaseDiscoveryMode(QStringLiteral("plugintest"));
 
             if (!d->loadedPlugins().contains(QStringLiteral("kdeconnect_remotecontrol"))) {
@@ -68,12 +75,12 @@ class PluginLoadTest : public QObject
             QVERIFY(d->isReachable());
 
             d->setPluginEnabled(QStringLiteral("kdeconnect_mousepad"), false);
-            QCOMPARE(d->isPluginEnabled("kdeconnect_mousepad"), false);
-            QVERIFY(d->supportedPlugins().contains("kdeconnect_remotecontrol"));
+            QCOMPARE(d->isPluginEnabled(QStringLiteral("kdeconnect_mousepad")), false);
+            QVERIFY(d->supportedPlugins().contains(QStringLiteral("kdeconnect_remotecontrol")));
 
             d->setPluginEnabled(QStringLiteral("kdeconnect_mousepad"), true);
-            QCOMPARE(d->isPluginEnabled("kdeconnect_mousepad"), true);
-            QVERIFY(d->supportedPlugins().contains("kdeconnect_remotecontrol"));
+            QCOMPARE(d->isPluginEnabled(QStringLiteral("kdeconnect_mousepad")), true);
+            QVERIFY(d->supportedPlugins().contains(QStringLiteral("kdeconnect_remotecontrol")));
         }
 
     private:
