@@ -15,11 +15,10 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <QSocketNotifier>
-#include <backends/lan/downloadjob.h>
 #include <kdeconnectconfig.h>
 #include <backends/lan/uploadjob.h>
 #include <core/filetransferjob.h>
@@ -38,6 +37,8 @@
 #include <backends/pairinghandler.h>
 #include "kdeconnect-version.h"
 #include "testdaemon.h"
+#include <plugins/share/shareplugin.h>
+#include <backends/lan/compositeuploadjob.h>
 
 class TestSendFile : public QObject
 {
@@ -50,6 +51,10 @@ class TestSendFile : public QObject
 
     private Q_SLOTS:
         void testSend() {
+            if (!(m_daemon->getLinkProviders().size() > 0)) {
+                QFAIL("No links available, but loopback should have been provided by the test");
+            }
+
             m_daemon->acquireDiscoveryMode(QStringLiteral("test"));
             Device* d = nullptr;
             const QList<Device*> devicesList = m_daemon->devicesList();
@@ -60,8 +65,10 @@ class TestSendFile : public QObject
                     d = id;
                 }
             }
+            if (d == nullptr) {
+                QFAIL("Unable to determine device");
+            }
             m_daemon->releaseDiscoveryMode(QStringLiteral("test"));
-            QVERIFY(d);
             QCOMPARE(d->isReachable(), true);
             QCOMPARE(d->isTrusted(), true);
 
@@ -91,44 +98,47 @@ class TestSendFile : public QObject
         void testSslJobs()
         {
             const QString aFile = QFINDTESTDATA("sendfiletest.cpp");
-            const QString destFile = QDir::tempPath() + "/kdeconnect-test-sentfile";
+            const QString destFile = QDir::tempPath() + QStringLiteral("/kdeconnect-test-sentfile");
             QFile(destFile).remove();
 
-            const QString deviceId = KdeConnectConfig::instance()->deviceId()
+            const QString deviceId = KdeConnectConfig::instance().deviceId()
                         , deviceName = QStringLiteral("testdevice")
-                        , deviceType = KdeConnectConfig::instance()->deviceType();
+                        , deviceType = KdeConnectConfig::instance().deviceType();
 
-            KdeConnectConfig* kcc = KdeConnectConfig::instance();
-            kcc->addTrustedDevice(deviceId, deviceName, deviceType);
-            kcc->setDeviceProperty(deviceId, QStringLiteral("certificate"), QString::fromLatin1(kcc->certificate().toPem())); // Using same certificate from kcc, instead of generating
+            KdeConnectConfig::instance().addTrustedDevice(deviceId, deviceName, deviceType);
+            KdeConnectConfig::instance().setDeviceProperty(deviceId, QStringLiteral("certificate"), QString::fromLatin1(KdeConnectConfig::instance().certificate().toPem())); // Using same certificate from kcc, instead of generating
+
+            //We need the device to be loaded on the daemon, otherwise CompositeUploadJob will get a null device
+            Device* device = new Device(this, deviceId);
+            m_daemon->addDevice(device);
 
             QSharedPointer<QFile> f(new QFile(aFile));
-            UploadJob* uj = new UploadJob(f, deviceId);
-            QSignalSpy spyUpload(uj, &KJob::result);
-            uj->start();
+            NetworkPacket np(PACKET_TYPE_SHARE_REQUEST);
+            np.setPayload(f, f->size());
 
-            auto info = uj->transferInfo();
-            info.insert(QStringLiteral("deviceId"), deviceId);
-            info.insert(QStringLiteral("size"), aFile.size());
+            CompositeUploadJob* job = new CompositeUploadJob(deviceId, false);
+            UploadJob* uj = new UploadJob(np);
+            job->addSubjob(uj);
 
-            DownloadJob* dj = new DownloadJob(QHostAddress::LocalHost, info);
+            QSignalSpy spyUpload(job, &KJob::result);
+            job->start();
 
-            QVERIFY(dj->getPayload()->open(QIODevice::ReadOnly));
+            f->open(QIODevice::ReadWrite);
 
-            FileTransferJob* ft = new FileTransferJob(dj->getPayload(), uj->transferInfo()[QStringLiteral("size")].toInt(), QUrl::fromLocalFile(destFile));
+            FileTransferJob* ft = np.createPayloadTransferJob(QUrl::fromLocalFile(destFile));
 
-            QSignalSpy spyDownload(dj, &KJob::result);
             QSignalSpy spyTransfer(ft, &KJob::result);
 
             ft->start();
-            dj->start();
 
-            QVERIFY(spyTransfer.count() || spyTransfer.wait(1000000000));
+            QVERIFY(spyTransfer.count() || spyTransfer.wait());
 
-            if (ft->error()) qWarning() << "fterror" << ft->errorString();
+            if (ft->error()) {
+                qWarning() << "fterror" << ft->errorString();
+            }
 
             QCOMPARE(ft->error(), 0);
-            QCOMPARE(spyDownload.count(), 1);
+
             QCOMPARE(spyUpload.count(), 1);
 
             QFile resultFile(destFile), originFile(aFile);
